``pyramid_ldap``
================

``pyramid_ldap`` provides LDAP authentication services for your Pyramid
application.  Thanks to the ever-awesome `SurveyMonkey
<http://surveymonkey.com>`_ for sponsoring the development of this package!

See the documentation at
https://docs.pylonsproject.org/projects/pyramid_ldap/en/latest/ for more
information.

This package will only work with Pyramid 1.3a9 and better.

